@@ -1,4 +1,5 @@
 """Tests for Google-style docstring routines."""
+
 import typing as T
 
 import pytest
@@ -28,6 +29,28 @@ def test_google_parser_unknown_section() -> None:
     assert len(docstring.meta) == 0
 
 
+def test_google_parser_multi_line_parameter_type() -> None:
+    """Test parsing a multi-line parameter type with default GoogleParser"""
+    parser = GoogleParser()
+    docstring = parser.parse(
+        """Description of the function.
+
+        Args:
+            output_type (Literal["searchResults", "sourcedAnswer",
+                "structured"]): The type of output.
+                This can be one of the following:
+                - "searchResults": Represents the search results.
+                - "sourcedAnswer": Represents a sourced answer.
+                - "structured": Represents a structured output format.
+
+        Returns:
+            bool: Indicates success or failure.
+
+        """
+    )
+    assert docstring.params[0].arg_name == "output_type"
+
+
 def test_google_parser_custom_sections() -> None:
     """Test parsing an unknown section with custom GoogleParser
     configuration.
